@@ -1,7 +1,10 @@
 class ExperimentDecision:
-    def __init__(self, variation, reason):
+    def __init__(self, variation, reason, config=None):
+        if config is None:
+            config = {}
         self.variation = variation
         self.reason = reason
+        self.config = config
 
     def __eq__(self, o):
         return self.variation == o.variation and self.reason == o.reason
@@ -10,16 +13,22 @@ class ExperimentDecision:
         return not self.__eq__(o)
 
     def __str__(self):
-        return '(variation={}, reason={})'.format(self.variation, self.reason)
+        return '(variation={}, reason={}, config={})'.format(self.variation, self.reason, self.config)
 
     def __repr__(self):
         return self.__str__()
 
+    def get(self, key, default=None):
+        return self.config.get(key, default)
+
 
 class FeatureFlagDecision:
-    def __init__(self, is_on, reason):
+    def __init__(self, is_on, reason, config=None):
+        if config is None:
+            config = {}
         self.is_on = is_on
         self.reason = reason
+        self.config = config
 
     def __eq__(self, o):
         return self.is_on == o.is_on and self.reason == o.reason
@@ -28,11 +37,14 @@ class FeatureFlagDecision:
         return not self.__eq__(o)
 
     def __str__(self):
-        return '(is_on={}, reason={})'.format(self.is_on, self.reason)
+        return '(is_on={}, reason={}, config={})'.format(self.is_on, self.reason, self.config)
 
     def __repr__(self):
         return self.__str__()
 
+    def get(self, key, default=None):
+        return self.config.get(key, default)
+
 
 class DecisionReason(object):
     SDK_NOK_READY = 'SDK_NOK_READY'
