@@ -39,10 +39,11 @@ class Experiment(BaseEntity):
 
 
 class Variation(BaseEntity):
-    def __init__(self, id, key, is_dropped):
+    def __init__(self, id, key, is_dropped, parameter_configuration_id=None):
         self.id = id
         self.key = key
         self.is_dropped = is_dropped
+        self.parameter_configuration_id = parameter_configuration_id
 
 
 class Bucket(BaseEntity):
@@ -153,3 +154,21 @@ class ContainerGroup(object):
     def __init__(self, id, experiments):
         self.id = id
         self.experiments = experiments
+
+
+class ParameterConfiguration(object):
+
+    def __init__(self, id, parameters):
+        self.id = id
+        self.parameters = parameters
+
+    def __str__(self):
+        return 'ParameterConfiguration(id={}, parameters={})'.format(self.id, self.parameters)
+
+    def get(self, key, default):
+        parameter_value = self.parameters.get(key, default)
+        if default is None:
+            return parameter_value
+        if type(parameter_value) != type(default):
+            return default
+        return parameter_value
