@@ -1,19 +1,30 @@
 import abc
 import time
 
+from hackle.user.identifier_type import IdentifierType
+
 ABC = abc.ABCMeta('ABC', (object,), {'__slots__': ()})
 
 
 class UserEvent(ABC):
     def __init__(self, user):
         self.timestamp = self._get_time()
-        self.userId = user.id
+        self.userId = user.identifiers.get(IdentifierType.ID)
+        self.identifiers = user.identifiers
         self.userProperties = user.properties
 
     # noinspection PyMethodMayBeStatic
     def _get_time(self):
         return int(round(time.time() * 1000))
 
+    @staticmethod
+    def exposure(experiment, user, evaluation):
+        return ExposureEvent(user, experiment, evaluation)
+
+    @staticmethod
+    def track(event_type, event, user):
+        return TrackEvent(user, event_type, event)
+
 
 class ExposureEvent(UserEvent):
     def __init__(self, user, experiment, evaluation):
@@ -26,6 +37,11 @@ class ExposureEvent(UserEvent):
         self.variationKey = evaluation.variation_key
         self.decisionReason = evaluation.reason
 
+        properties = {}
+        if evaluation.config is not None:
+            properties['$parameterConfigurationId'] = evaluation.config.id
+        self.properties = properties
+
 
 class TrackEvent(UserEvent):
     def __init__(self, user, event_type, event):
