@@ -1,12 +1,15 @@
-from hackle.evaluation.evaluator import Evaluator
-from hackle.evaluation.flow.evaluation_flow_factory import EvaluationFlowFactory
-from hackle import exceptions as hackle_exceptions
-from hackle import logger as _logging
-from hackle.decision import ExperimentDecision, DecisionReason, FeatureFlagDecision
-from hackle.event.event_dispatcher import EventDispatcher
-from hackle.event.event_processor import BatchEventProcessor
-from hackle.internal_client import InternalClient
-from hackle.workspace_fetcher import WorkspaceFetcher
+from . import exceptions as hackle_exceptions
+from . import logger as _logging
+from .commons import utils
+from .commons import validator
+from .decision import ExperimentDecision, DecisionReason, FeatureFlagDecision
+from .evaluation.evaluator import Evaluator
+from .evaluation.flow.evaluation_flow_factory import EvaluationFlowFactory
+from .event.event_dispatcher import EventDispatcher
+from .event.event_processor import BatchEventProcessor
+from .internal_client import InternalClient
+from .user.hackle_user_resolver import HackleUserResolver
+from .workspace_fetcher import WorkspaceFetcher
 
 
 def __singleton(cls):
@@ -35,6 +38,8 @@ class Client(object):
             logger=self.logger
         )
 
+        self.hackle_user_resolver = HackleUserResolver(logger)
+
     def close(self):
         self.internal_client.close()
 
@@ -52,7 +57,7 @@ class Client(object):
             - The decided variation has been dropped
 
         :param int experiment_key: the unique key of the experiment.
-        :param hackle.model.User user: the user to participate in the experiment.
+        :param hackle.model.User or hackle.model.HackleUser user: the user to participate in the experiment.
         :param str default_variation: the default variation of the experiment.
 
         :return: the decided variation for the user, or the default variation.
@@ -65,13 +70,21 @@ class Client(object):
         describes the way the variation was decided.
 
         :param int experiment_key: the unique key of the experiment.
-        :param hackle.model.User user: the user to participate in the experiment.
+        :param hackle.model.User or hackle.model.HackleUser user: the user to participate in the experiment.
         :param str default_variation: the default variation of the experiment.
 
         :return: a object describing the result
         """
         try:
-            return self.internal_client.decide_experiment(experiment_key, user, default_variation)
+            if not validator.is_non_zero_and_empty_int(experiment_key):
+                self.logger.error('Experiment Key must not be empty. : {}'.format(experiment_key))
+                return ExperimentDecision(default_variation, DecisionReason.INVALID_INPUT)
+
+            hackle_user = self.hackle_user_resolver.resolve_or_none(user)
+            if hackle_user is None:
+                return ExperimentDecision(default_variation, DecisionReason.INVALID_INPUT)
+
+            return self.internal_client.experiment(experiment_key, hackle_user, default_variation)
         except Exception as e:
             self.logger.error(
                 "Unexpected error while deciding variation of experiment[{}]: {}".format(experiment_key, str(e)))
@@ -82,7 +95,7 @@ class Client(object):
         Decide whether the feature is turned on to the user.
 
         :param int feature_key: the unique key of the feature.
-        :param hackle.model.User user: the user requesting the feature.
+        :param hackle.model.User or hackle.model.HackleUser user: the user to participate in the experiment.
         :return: True if the feature is on
                   False if the feature is off
         """
@@ -94,12 +107,21 @@ class Client(object):
         describes the way the value was decided.
 
         :param int feature_key: the unique key of the feature.
-        :param hackle.model.User user: the user requesting the feature.
+        :param hackle.model.User or hackle.model.HackleUser user: the user to participate in the experiment.
 
         :return: a object describing the result
         """
         try:
-            return self.internal_client.decide_feature_flag(feature_key, user)
+
+            if not validator.is_non_zero_and_empty_int(feature_key):
+                self.logger.error('Experiment Key must not be empty. : {}'.format(feature_key))
+                return FeatureFlagDecision(False, DecisionReason.INVALID_INPUT)
+
+            hackle_user = self.hackle_user_resolver.resolve_or_none(user)
+            if hackle_user is None:
+                return FeatureFlagDecision(False, DecisionReason.INVALID_INPUT)
+
+            return self.internal_client.feature_flag(feature_key, hackle_user)
         except Exception as e:
             self.logger.error("Unexpected error while deciding feature flag[{}]: {}".format(feature_key, str(e)))
             return FeatureFlagDecision(False, DecisionReason.EXCEPTION)
@@ -109,9 +131,25 @@ class Client(object):
         Records the event performed by the user with additional numeric value.
 
         :param hackle.model.Event event: the unique key of the event. MUST NOT be null.
-        :param user: the identifier of user that performed the event. MUST NOT be null.
+        :param hackle.model.User or hackle.model.HackleUser user: the user to participate in the experiment.
         """
         try:
-            self.internal_client.track_event(event, user)
+            if not validator.is_valid_event(event):
+                self.logger.error('Event is not valid. Event must be hackle.model.event and event.id\'s type must be '
+                                  'string_types. value\'s type must be numeric. '
+                                  ': {}'.format(event))
+                return
+
+            if not validator.is_valid_properties(event.properties):
+                self.logger.warning(
+                    'Event properties is not valid. Event properties must be not dic types and items types must be string_types, number, bool.'
+                    ': {}'.format(event.properties))
+                event.properties = utils.filter_properties(event.properties)
+
+            hackle_user = self.hackle_user_resolver.resolve_or_none(user)
+            if hackle_user is None:
+                return
+
+            self.internal_client.track_event(event, hackle_user)
         except Exception as e:
             self.logger.error('Unexpected error while tracking event: {}'.format(str(e)))
