@@ -13,6 +13,8 @@ class Workspace(object):
         self.event_type_key_map = self._event_type_key_map(json_data.get('events', []))
         self.segment_key_map = self._segment_key_map(json_data.get('segments', []))
         self._container_id_map = self._container_id_map(json_data.get('containers', []))
+        self.parameter_configurations = self._parameter_configuration_id_map(
+            json_data.get('parameterConfigurations', []))
 
     def get_experiment_or_none(self, experiment_key):
         return self.experiment_key_map.get(experiment_key)
@@ -32,6 +34,9 @@ class Workspace(object):
     def get_container_or_none(self, container_id):
         return self._container_id_map.get(container_id)
 
+    def get_parameter_configuration_or_none(self, parameter_configuration_id):
+        return self.parameter_configurations.get(parameter_configuration_id)
+
     @staticmethod
     def _bucket_id_map(buckets_data):
         bucket_id_map = {}
@@ -76,7 +81,8 @@ class Workspace(object):
             variation = Variation(
                 id=variation_data['id'],
                 key=variation_data['key'],
-                is_dropped=variation_data['status'] == 'DROPPED'
+                is_dropped=variation_data['status'] == 'DROPPED',
+                parameter_configuration_id=variation_data.get('parameterConfigurationId')
             )
             variations.append(variation)
 
@@ -252,3 +258,18 @@ class Workspace(object):
             id=container_group_data['id'],
             experiments=container_group_data['experiments']
         )
+
+    @staticmethod
+    def _parameter_configuration_id_map(parameter_configurations_data):
+        _parameter_configuration_id_map = {}
+        for parameter_configuration_data in parameter_configurations_data:
+            parameters = {}
+            for parameter in parameter_configuration_data['parameters']:
+                parameters[parameter['key']] = parameter['value']
+
+            parameter_configuration = ParameterConfiguration(
+                id=parameter_configuration_data['id'],
+                parameters=parameters
+            )
+            _parameter_configuration_id_map[parameter_configuration.id] = parameter_configuration
+        return _parameter_configuration_id_map
