@@ -5,10 +5,10 @@ import traceback
 import requests
 from requests import exceptions as requests_exceptions
 
-from hackle import logger as hackle_logger
-from hackle import version
-from hackle.commons import enums
-from hackle.workspace import Workspace
+from . import logger as hackle_logger
+from . import version
+from .commons import enums
+from .workspace import Workspace
 
 
 class WorkspaceFetcher(object):
@@ -31,7 +31,7 @@ class WorkspaceFetcher(object):
             self.logger.error('Failed to pool Workspace: {}'.format(err))
             return
 
-        self._set_workspace(response.content)
+        self._set_workspace(response.content.decode('utf-8'))
 
     def fetch(self):
         request_headers = {enums.Default.SDK_KEY_HEADER: self.sdk_key,
